libpysal Tutorial
=================


Spatial Weights
---------------

.. toctree::
    :glob:

    Spatial Weights <notebooks/weights.ipynb>
    Voronoi <notebooks/voronoi.ipynb>


Example Datasets
----------------

.. toctree::
    :glob:

    Example Data <notebooks/examples.ipynb>